(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('rxjs/Subject')) :
	typeof define === 'function' && define.amd ? define('ooi-tabbed-wizard', ['exports', '@angular/core', 'rxjs/Subject'], factory) :
	(factory((global['ooi-tabbed-wizard'] = {}),global.ng.core,global.Rx));
}(this, (function (exports,core,Subject) { 'use strict';

var WizardEventService = (function () {
    function WizardEventService() {
        this.notify = new Subject.Subject();
        this.notifyObservable$ = this.notify.asObservable();
    }
    WizardEventService.prototype.notifyOther = function (event) {
        this.notify.next(event);
    };
    return WizardEventService;
}());
WizardEventService.decorators = [
    { type: core.Injectable },
];
var TabbedWizardComponent = (function () {
    function TabbedWizardComponent(wizardEventService) {
        this.wizardEventService = wizardEventService;
        this.onTabChanged = new core.EventEmitter();
        this.tabs = [];
        this.numberOfTabs = 0;
    }
    TabbedWizardComponent.prototype.ngOnInit = function () {
        var _this = this;
        this.subscription = this.wizardEventService.notifyObservable$.subscribe(function (event) {
            switch (event.type) {
                case 'continue':
                    _this.goToNextTab();
                    break;
                case 'completeActiveTab':
                    _this.tabs.forEach(function (tab) {
                        if (tab.active && !tab.completed) {
                            tab.completed = true;
                            if (tab.index < _this.tabs.length - 1) {
                                tab.isCurrentStep = false;
                                _this.tabs[tab.index + 1].isCurrentStep = true;
                            }
                        }
                    });
                    break;
            }
        });
    };
    TabbedWizardComponent.prototype.ngOnDestroy = function () {
        this.subscription.unsubscribe();
    };
    TabbedWizardComponent.prototype.addTab = function (tab) {
        if (this.tabs.length == 0) {
            tab.active = true;
            tab.isCurrentStep = true;
        }
        tab.index = this.numberOfTabs;
        this.tabs.push(tab);
        this.numberOfTabs++;
    };
    TabbedWizardComponent.prototype.showTab = function (clickedTab) {
        if (clickedTab == this.tabs[0] || this.tabs[clickedTab.index - 1].completed) {
            this.tabs.forEach(function (tab) {
                tab.active = false;
            });
            clickedTab.active = true;
        }
        this.onTabChanged.emit(clickedTab);
    };
    TabbedWizardComponent.prototype.goToNextTab = function () {
        var activeTab = this.getActiveTab();
        if (activeTab.index >= this.tabs.length - 1)
            console.log('You tried to continue past the last step.');
        else
            this.showTab(this.tabs[activeTab.index + 1]);
    };
    TabbedWizardComponent.prototype.getActiveTab = function () {
        return this.tabs.find(function (tab) {
            return tab.active == true;
        });
    };
    return TabbedWizardComponent;
}());
TabbedWizardComponent.decorators = [
    { type: core.Component, args: [{
                selector: 'tabbed-wizard',
                template: "<div class=\"wizard-tab-container\">\n  <div class=\"logo-container\">\n    <img [src]=\"logoUrl\" class=\"logo\" />\n  </div>\n  <div class=\"wizard-steps\">\n    <div *ngFor=\"let tab of tabs\"\n        (click)=\"showTab(tab)\"\n        [ngClass]=\"{\n          'active': tab.active,\n          'completed': tab.completed,\n          'current-step': tab.isCurrentStep\n        }\"\n        class=\"wizard-step\">\n      <div class=\"completed-indicator\"\n        [hidden]=\"!tab.completed\"></div>\n      <div class=\"current-step-indicator\"\n        [hidden]=\"!tab.isCurrentStep\">\n        <div class=\"down-arrow\"></div>\n      </div>\n      <div class=\"wizard-step-template-container\">\n        <ng-template [ngTemplateOutlet]=\"tab.thumbnailTemplate\"></ng-template>\n      </div>\n      <div class=\"arrow\"></div>\n    </div>\n    <div class=\"filler\">\n    </div>\n  </div>\n</div>\n<ng-content></ng-content>\n",
                styles: [".wizard-tab-container{color:#ccc;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:left;-ms-flex-pack:left;justify-content:left;background-color:#2d2d2d}.wizard-tab-container .wizard-steps{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:left;-ms-flex-pack:left;justify-content:left}.wizard-tab-container .logo-container{width:20%;padding:27px 19px;border-bottom:2px solid #0079a1;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;max-height:150px;max-width:310px}.wizard-tab-container .logo-container .logo{width:100%}.wizard-tab-container .wizard-step:first-child{border-left:2px solid #b0b4a6}.wizard-tab-container .wizard-step:nth-last-child(2) .arrow{display:none}.wizard-tab-container .wizard-step{position:relative;padding:2px;border:2px solid #b0b4a6;border-left:none;cursor:not-allowed}.wizard-tab-container .wizard-step .wizard-step-template-container{margin-top:11px}.wizard-tab-container .wizard-step .completed-indicator{width:100%;height:5px;background:#0079a1;margin-bottom:6px}.wizard-tab-container .wizard-step .current-step-indicator{width:100%;height:5px;background:#0079a1;position:relative;margin-bottom:6px}.wizard-tab-container .wizard-step .current-step-indicator .down-arrow{position:absolute;left:50%;top:5px;margin-left:-6px;width:0;height:0;border-width:6px;border-color:#0079a1 transparent transparent;border-style:solid}.wizard-tab-container .wizard-step .arrow{width:10px;height:10px;border-right:2px solid #b0b4a6;border-bottom:2px solid #b0b4a6;position:absolute;right:-6px;top:50%;margin-top:-5px;-webkit-transform:rotate(-45deg);transform:rotate(-45deg);background:#2d2d2d;z-index:100}.wizard-tab-container .wizard-step.completed{border-color:#0079a1;cursor:pointer}.wizard-tab-container .wizard-step.completed .wizard-step-template-container{margin-top:0}.wizard-tab-container .wizard-step.completed .arrow{border-color:#0079a1}.wizard-tab-container .wizard-step.active{background:-webkit-gradient(linear,left bottom,left top,from(#2d2d2d),color-stop(80%,#555),to(#565656));background:linear-gradient(0deg,#2d2d2d,#555 80%,#565656);border-color:#0079a1;cursor:pointer;border-bottom:none}.wizard-tab-container .wizard-step.active .arrow{background:#444;border-right-color:#0079a1;border-bottom-color:#0079a1}.wizard-tab-container .wizard-step.current-step{cursor:pointer}.wizard-tab-container .wizard-step.current-step .wizard-step-template-container{margin-top:0}.wizard-tab-container .filler{width:100%;border-bottom:2px solid #b0b4a6}.wizard-tab-container .filler.completed{border-color:#0079a1}"]
            },] },
];
TabbedWizardComponent.ctorParameters = function () { return [
    { type: WizardEventService }
]; };
TabbedWizardComponent.propDecorators = {
    logoUrl: [{ type: core.Input }],
    logoHeight: [{ type: core.Input }],
    onTabChanged: [{ type: core.Output }]
};
var WizardTabComponent = (function () {
    function WizardTabComponent(wizard) {
        this.active = false;
        this.completed = false;
        this.isCurrentStep = false;
        this.index = 0;
        wizard.addTab(this);
    }
    WizardTabComponent.prototype.ngOnInit = function () { };
    return WizardTabComponent;
}());
WizardTabComponent.decorators = [
    { type: core.Component, args: [{
                selector: 'wizard-tab',
                template: "<div class=\"wizard-content\"\n    [hidden]=\"!active\">\n  <ng-template [ngTemplateOutlet]=\"contentTemplate\"></ng-template>\n</div>\n",
                styles: [""]
            },] },
];
WizardTabComponent.ctorParameters = function () { return [
    { type: TabbedWizardComponent }
]; };
WizardTabComponent.propDecorators = {
    thumbnailTemplate: [{ type: core.ContentChild, args: ['tabThumbnail',] }],
    contentTemplate: [{ type: core.ContentChild, args: ['tabContent',] }]
};

exports.ɵc = TabbedWizardComponent;
exports.ɵa = WizardEventService;
exports.ɵb = WizardTabComponent;

Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ooi-tabbed-wizard.umd.js.map
