import { Injectable, Component, EventEmitter, Input, Output, ContentChild } from '@angular/core';
import { Subject } from 'rxjs/Subject';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * @record
 */

class WizardEventService {
    constructor() {
        this.notify = new Subject();
        this.notifyObservable$ = this.notify.asObservable();
    }
    /**
     * @param {?} event
     * @return {?}
     */
    notifyOther(event) {
        this.notify.next(event);
    }
}
WizardEventService.decorators = [
    { type: Injectable },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class TabbedWizardComponent {
    /**
     * @param {?} wizardEventService
     */
    constructor(wizardEventService) {
        this.wizardEventService = wizardEventService;
        this.onTabChanged = new EventEmitter();
        this.tabs = [];
        this.numberOfTabs = 0;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.subscription = this.wizardEventService.notifyObservable$.subscribe((event) => {
            switch (event.type) {
                case 'continue':
                    this.goToNextTab();
                    break;
                case 'completeActiveTab':
                    this.tabs.forEach((tab) => {
                        if (tab.active && !tab.completed) {
                            tab.completed = true;
                            if (tab.index < this.tabs.length - 1) {
                                tab.isCurrentStep = false;
                                this.tabs[tab.index + 1].isCurrentStep = true;
                            }
                        }
                    });
                    break;
            }
        });
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.subscription.unsubscribe();
    }
    /**
     * @param {?} tab
     * @return {?}
     */
    addTab(tab) {
        if (this.tabs.length == 0) {
            tab.active = true;
            tab.isCurrentStep = true;
        }
        tab.index = this.numberOfTabs;
        this.tabs.push(tab);
        this.numberOfTabs++;
    }
    /**
     * @param {?} clickedTab
     * @return {?}
     */
    showTab(clickedTab) {
        if (clickedTab == this.tabs[0] || this.tabs[clickedTab.index - 1].completed) {
            this.tabs.forEach((tab) => {
                tab.active = false;
            });
            clickedTab.active = true;
        }
        this.onTabChanged.emit(clickedTab);
    }
    /**
     * @return {?}
     */
    goToNextTab() {
        let /** @type {?} */ activeTab = this.getActiveTab();
        if (activeTab.index >= this.tabs.length - 1)
            console.log('You tried to continue past the last step.');
        else
            this.showTab(this.tabs[activeTab.index + 1]);
    }
    /**
     * @return {?}
     */
    getActiveTab() {
        return this.tabs.find((tab) => {
            return tab.active == true;
        });
    }
}
TabbedWizardComponent.decorators = [
    { type: Component, args: [{
                selector: 'tabbed-wizard',
                template: `<div class="wizard-tab-container">
  <div class="logo-container">
    <img [src]="logoUrl" class="logo" />
  </div>
  <div class="wizard-steps">
    <div *ngFor="let tab of tabs"
        (click)="showTab(tab)"
        [ngClass]="{
          'active': tab.active,
          'completed': tab.completed,
          'current-step': tab.isCurrentStep
        }"
        class="wizard-step">
      <div class="completed-indicator"
        [hidden]="!tab.completed"></div>
      <div class="current-step-indicator"
        [hidden]="!tab.isCurrentStep">
        <div class="down-arrow"></div>
      </div>
      <div class="wizard-step-template-container">
        <ng-template [ngTemplateOutlet]="tab.thumbnailTemplate"></ng-template>
      </div>
      <div class="arrow"></div>
    </div>
    <div class="filler">
    </div>
  </div>
</div>
<ng-content></ng-content>
`,
                styles: [`.wizard-tab-container{color:#ccc;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:left;-ms-flex-pack:left;justify-content:left;background-color:#2d2d2d}.wizard-tab-container .wizard-steps{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:left;-ms-flex-pack:left;justify-content:left}.wizard-tab-container .logo-container{width:20%;padding:27px 19px;border-bottom:2px solid #0079a1;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;max-height:150px;max-width:310px}.wizard-tab-container .logo-container .logo{width:100%}.wizard-tab-container .wizard-step:first-child{border-left:2px solid #b0b4a6}.wizard-tab-container .wizard-step:nth-last-child(2) .arrow{display:none}.wizard-tab-container .wizard-step{position:relative;padding:2px;border:2px solid #b0b4a6;border-left:none;cursor:not-allowed}.wizard-tab-container .wizard-step .wizard-step-template-container{margin-top:11px}.wizard-tab-container .wizard-step .completed-indicator{width:100%;height:5px;background:#0079a1;margin-bottom:6px}.wizard-tab-container .wizard-step .current-step-indicator{width:100%;height:5px;background:#0079a1;position:relative;margin-bottom:6px}.wizard-tab-container .wizard-step .current-step-indicator .down-arrow{position:absolute;left:50%;top:5px;margin-left:-6px;width:0;height:0;border-width:6px;border-color:#0079a1 transparent transparent;border-style:solid}.wizard-tab-container .wizard-step .arrow{width:10px;height:10px;border-right:2px solid #b0b4a6;border-bottom:2px solid #b0b4a6;position:absolute;right:-6px;top:50%;margin-top:-5px;-webkit-transform:rotate(-45deg);transform:rotate(-45deg);background:#2d2d2d;z-index:100}.wizard-tab-container .wizard-step.completed{border-color:#0079a1;cursor:pointer}.wizard-tab-container .wizard-step.completed .wizard-step-template-container{margin-top:0}.wizard-tab-container .wizard-step.completed .arrow{border-color:#0079a1}.wizard-tab-container .wizard-step.active{background:-webkit-gradient(linear,left bottom,left top,from(#2d2d2d),color-stop(80%,#555),to(#565656));background:linear-gradient(0deg,#2d2d2d,#555 80%,#565656);border-color:#0079a1;cursor:pointer;border-bottom:none}.wizard-tab-container .wizard-step.active .arrow{background:#444;border-right-color:#0079a1;border-bottom-color:#0079a1}.wizard-tab-container .wizard-step.current-step{cursor:pointer}.wizard-tab-container .wizard-step.current-step .wizard-step-template-container{margin-top:0}.wizard-tab-container .filler{width:100%;border-bottom:2px solid #b0b4a6}.wizard-tab-container .filler.completed{border-color:#0079a1}`]
            },] },
];
/** @nocollapse */
TabbedWizardComponent.ctorParameters = () => [
    { type: WizardEventService }
];
TabbedWizardComponent.propDecorators = {
    logoUrl: [{ type: Input }],
    logoHeight: [{ type: Input }],
    onTabChanged: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class WizardTabComponent {
    /**
     * @param {?} wizard
     */
    constructor(wizard) {
        this.active = false;
        this.completed = false;
        this.isCurrentStep = false;
        this.index = 0;
        wizard.addTab(this);
    }
    /**
     * @return {?}
     */
    ngOnInit() { }
}
WizardTabComponent.decorators = [
    { type: Component, args: [{
                selector: 'wizard-tab',
                template: `<div class="wizard-content"
    [hidden]="!active">
  <ng-template [ngTemplateOutlet]="contentTemplate"></ng-template>
</div>
`,
                styles: [``]
            },] },
];
/** @nocollapse */
WizardTabComponent.ctorParameters = () => [
    { type: TabbedWizardComponent }
];
WizardTabComponent.propDecorators = {
    thumbnailTemplate: [{ type: ContentChild, args: ['tabThumbnail',] }],
    contentTemplate: [{ type: ContentChild, args: ['tabContent',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { TabbedWizardComponent as ɵc, WizardEventService as ɵa, WizardTabComponent as ɵb };
//# sourceMappingURL=ooi-tabbed-wizard.js.map
